@@ -389,3 +389,49 @@ fn distance() {
     assert_eq!(g.distance((3, 2), (5, 7)), 5);
     assert_eq!(g.distance((5, 7), (3, 2)), 5);
 }
+
+#[test]
+fn debug() {
+    let g = [
+        (0, 0),
+        (1, 0),
+        (2, 0),
+        (3, 0),
+        (4, 0),
+        (0, 1),
+        (4, 1),
+        (0, 2),
+        (4, 2),
+        (0, 3),
+        (4, 3),
+        (0, 4),
+        (1, 4),
+        (2, 4),
+        (3, 4),
+        (4, 4),
+    ]
+    .into_iter()
+    .collect::<Grid>();
+    assert_eq!(
+        format!("{:?}", g),
+        String::from(
+            "\
+#####
+#...#
+#...#
+#...#
+#####"
+        )
+    );
+    assert_eq!(
+        format!("{:#?}", g),
+        String::from(
+            "\
+▓▓▓▓▓
+▓░░░▓
+▓░░░▓
+▓░░░▓
+▓▓▓▓▓"
+        )
+    );
+}
